plot_photo_timeline: Plot a Timeline of Renamed Nest Box Photos

Description Usage Arguments Examples

View source: R/plot_photo_timeline.R

Description

After all of the photos have been renamed, plot a timeline of all of the photos taken by nest box ID. Photos will be shown in the plot with a '|' mark.

Usage

1
plot_photo_timeline(directory_to_drive, renamed_photo_location)

Arguments

directory_to_drive

folder for research drive

renamed_photo_location

folder where renamed photos are stored

Examples

1
plot_photo_timeline(directory_to_drive, renamed_photo_location)

jaymwin/nestboxphotos documentation built on Jan. 10, 2020, 1:50 a.m.